==> haskell-hie-bios-0.12.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-6yOk2Dy2R6HIvWDDPiWnxF
key:                  hie-bios-0.12.0-6yOk2Dy2R6HIvWDDPiWnxF
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  2229f06973ffac2089b23d1988b989d6
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-6yOk2Dy2R6HIvWDDPiWnxF
depends:
    aeson-2.1.2.1-DotSWK7wQi51TFnSZ5tWn0 base-4.17.2.1
    base16-bytestring-1.0.2.0-L60Rqi32njv1QNA4jOe3ZV
    bytestring-0.11.5.3 co-log-core-0.3.2.5-4hQp3hwpV9NJKGuCwP8VfL
    conduit-1.3.6.1-9gTixXdrGe0HqsCoF12xcT
    conduit-extra-1.3.6-L20sNRqRGruUiEEr6OeGd
    cryptohash-sha1-0.11.101.0-CKxVq2LIxfzF3uHwiR13xj deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-4FmiJFMCPWcB9FEOd1mu2u
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-8GOcgjQxfRo9PWq0pydGGO
    template-haskell-2.19.0.0 temporary-1.3-8FAts4F1AmtHqh7aYyLCzN
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.3-DV17HkZ4p37LF0rLylNPml
    unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne
    yaml-0.11.11.2-2OEKadT5HvfGp7KZlKd4Jd

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-6PEIyUxPSveJV8Aqs4qicv
key:                  hie-bios-0.12.0-6PEIyUxPSveJV8Aqs4qicv
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  cf18586929863a1ea60a1622e360347d
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-6PEIyUxPSveJV8Aqs4qicv
depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1
    base16-bytestring-1.0.2.0-L60Rqi32njv1QNA4jOe3ZV
    bytestring-0.11.5.3 co-log-core-0.3.2.5-4hQp3hwpV9NJKGuCwP8VfL
    conduit-1.3.6.1-LEKlJ5sjhOMOY4BoQvHAk
    conduit-extra-1.3.6-2wqo8ucVt5IGPwh2HHGSdk
    cryptohash-sha1-0.11.101.0-CKxVq2LIxfzF3uHwiR13xj deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-5m7TC0OmR1yJEj0luDg7V3
    file-embed-0.0.15.0-7OnjuFj6gBM9fqBKJCVXdU filepath-1.4.2.2
    ghc-9.4.8 prettyprinter-1.7.1-L5f5fQ72tN6KrwJu1IwhTZ
    template-haskell-2.19.0.0 temporary-1.3-8FAts4F1AmtHqh7aYyLCzN
    text-2.0.2 time-1.12.2 transformers-0.5.6.2
    unix-compat-0.7.3-4KjQwvobFGi5CULM8PAvE4
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    yaml-0.11.11.2-3iCu9PejHEs3WcXBwsqmql

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
